@@ -12,7 +12,8 @@ from sentence_transformers import SentenceTransformer
 
 
 class ContextualDocs:
-    def __init__(self, model="paraphrase-xlm-r-multilingual-v1"):
+    
+    def __init__(self, model="all-mpnet-base-v2"):
         """
         Class initialization method.
 
@@ -27,11 +28,14 @@ class ContextualDocs:
         except Exception as es:
             logging.info(es)
 
+            
     def fit(self, documents):
         """
         :param documents: The input set of documents.
         """
+        pass
 
+    
     def transform(self, documents):
         """
         :param documents: The input set of documents.
@@ -54,12 +58,14 @@ class ContextualDocs:
         self.ndim = encoded_documents.shape[1]
         return encoded_documents
 
+    
     def fit_transform(self, documents, b=None):
         """
         :param documents: The input set of documents.
         """
         return self.transform(documents)
 
+    
     def get_feature_names(self):
         """
         :param fnames: Feature names (custom api artefact)
@@ -67,13 +73,12 @@ class ContextualDocs:
 
         return [f"dim_{x}" for x in range(self.ndim)]
 
-
 if __name__ == "__main__":
 
     import pandas as pd
 
-    example_text = pd.read_csv("../data/insults/train.tsv", sep="\t")['text_a']
-    labels = pd.read_csv("../data/insults/train.tsv",
+    example_text = pd.read_csv("../data/dontpatronize/train.tsv", sep="\t")['text_a']
+    labels = pd.read_csv("../data/dontpatronize/train.tsv",
                          sep="\t")['label'].values.tolist()
     clx = ContextualDocs()
     sim_features = clx.fit_transform(example_text)
