@@ -9,7 +9,7 @@ import itertools
 import numpy as np
 import tqdm
 from sklearn.neighbors import KNeighborsClassifier, KNeighborsRegressor
-from sklearn.model_selection import GridSearchCV, ShuffleSplit
+from sklearn.model_selection import GridSearchCV, ShuffleSplit, RandomizedSearchCV
 from sklearn.linear_model import SGDClassifier, SGDRegressor
 from scipy import sparse
 from collections import defaultdict, Counter
@@ -19,7 +19,6 @@ import operator
 import copy
 from deap import base, creator, tools
 import logging
-import wget  # For conceptnet download if necessary
 logging.basicConfig(format='%(asctime)s - %(message)s',
                     datefmt='%d-%b-%y %H:%M:%S')
 logging.getLogger().setLevel(logging.INFO)
@@ -1000,6 +999,9 @@ class GAlearner:
 
         instances=self.return_dataframe_from_text(instances)
         output_representation=self.vectorizer.transform(instances)
+
+        
+        
         return output_representation
 
     def predict(self, instances):
