@@ -6,7 +6,7 @@ import pandas as pd
 
 def run():
     ## Load example data frame
-    dataframe = pd.read_csv("../data/insults/train.tsv", sep="\t")
+    dataframe = pd.read_csv("../data/depression/train.tsv", sep="\t")
     train_sequences = dataframe['text_a']
     train_targets = dataframe['label']
 
